@@ -2,4 +2,6 @@ __version__ = '1.0.1'
 from jsw_nx.base.set import set
 from jsw_nx.base.forin import forin
 from jsw_nx.base.get import get
+from jsw_nx.base.indexof import indexof
+from jsw_nx.base.includes import includes
 from jsw_nx.packages.days import days
